@@ -28,31 +28,25 @@ clust.cond.info <- function (x = NULL,
   Conds <- (as.data.frame(do.call("rbind", strsplit(row.names(DATA), "_")))[1])
   ForNorm1 <- as.data.frame(table(Conds))
   ForNorm <- min(ForNorm1$Freq)
+  SizeFactors <- round(ForNorm1$Freq/ForNorm,3)
+  ForNorm1$SF <- SizeFactors
+  #
   clusts <- (as.data.frame(DATA$clusters))
   cond.clust <- cbind(Conds, clusts)
   colnames(cond.clust) <- c("conditions","clusters")
   Conds <- as.character(ForNorm1$Conds)
   My.Conds.data <- cond.clust
-  for (i in Conds) {
-    NameCol <- paste("My_Cond",i,sep="_")
-    myDATA <- head(subset(My.Conds.data, My.Conds.data$conditions == i),ForNorm)
-    eval(call("<-", as.name(NameCol), myDATA))
-  }
-  filenames <- ls(pattern="My_Cond_")
-  datalist <- mget(filenames)
-  NormDATA <- do.call(rbind.data.frame,datalist)
-  if (normalize.ncell == TRUE) {
-    cond.clust <- NormDATA
-  }
+  #################
   DATA <- as.data.frame(table(cond.clust))
   Freq <- DATA$Freq
-  if (normalize.ncell == TRUE) {
-    colnames(DATA) <- c("conditions","clusters","NormalizedFreq")
-  }
+  colnames(ForNorm1) <- c("conditions","TC","SF")
+  DATA <- merge(ForNorm1,DATA,by="conditions")
+  DATA$Norm.Freq <- round(DATA$Freq/DATA$SF,3)
+################
 # as.data.frame(table(Conds))
   # bar
-  myBP <- ggplot(DATA,aes(y=Freq, x=clusters, fill = conditions)) +
-   geom_bar(stat = "identity") + theme_bw() + theme(axis.text.x=element_text(angle=90))
+  myBP <- ggplot(DATA,aes(y=Freq, x=conditions, fill = conditions)) +
+    geom_bar(stat = "identity") + theme_bw() + theme(axis.text.x=element_text(angle=90)) + facet_wrap(~ clusters)
   # pie
   myPIE <- ggplot(DATA,aes(y=Freq, x="", fill = conditions)) +
     geom_bar(stat = "identity", position = "fill") + theme_bw() + facet_wrap(~ clusters) +
@@ -60,6 +54,17 @@ clust.cond.info <- function (x = NULL,
       axis.text.y=element_blank(),
       axis.ticks.y=element_blank()) + coord_polar(theta="y")
   #############
+  if (normalize.ncell == TRUE) {
+    # bar
+    myBP <- ggplot(DATA,aes(y=Norm.Freq, x=conditions, fill = conditions)) +
+      geom_bar(stat = "identity") + theme_bw() + theme(axis.text.x=element_text(angle=90)) + facet_wrap(~ clusters)
+    # pie
+    myPIE <- ggplot(DATA,aes(y=Norm.Freq, x="", fill = conditions)) +
+      geom_bar(stat = "identity", position = "fill") + theme_bw() + facet_wrap(~ clusters) +
+      theme(axis.title.y=element_blank(),
+            axis.text.y=element_blank(),
+            axis.ticks.y=element_blank()) + coord_polar(theta="y")
+  }
 #  write.table((DATA), file="clust_cond_freq_info.txt", sep="\t", row.names =FALSE)
 #  message("clust_cond_freq_info.txt file has beed generated.")
   if (my.out.put == "plot") {
