@@ -75,5 +75,9 @@ utils::globalVariables(c("%>%",
                          "FindIntegrationAnchors",
                          "FindVariableFeatures",
                          "DiffusionMap",
+                         "SCTransform",
+                         "Norm.Freq",
+                         "SelectIntegrationFeatures",
+                         "PrepSCTIntegration",
                          "Phase",
                          "yend"))
